/****************************************************************************
** Meta object code from reading C++ file 'incidencemodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../calindori-26.07.90/src/incidencemodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'incidencemodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14IncidenceModelE_t {};
} // unnamed namespace

template <> constexpr inline auto IncidenceModel::qt_create_metaobjectdata<qt_meta_tag_ZN14IncidenceModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "IncidenceModel",
        "filterDtChanged",
        "",
        "filterHourChanged",
        "filterHideCompletedChanged",
        "calendarFilterChanged",
        "calendarChanged",
        "filterModeChanged",
        "appLocaleChanged",
        "filterMode",
        "filterDt",
        "filterHour",
        "filterHideCompleted",
        "appLocale",
        "Status",
        "StatusNone",
        "StatusTentative",
        "StatusConfirmed",
        "StatusCompleted",
        "StatusNeedsAction",
        "StatusCanceled",
        "StatusInProcess",
        "StatusDraft",
        "StatusFinal",
        "StatusX"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'filterDtChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterHourChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterHideCompletedChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'calendarFilterChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'calendarChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterModeChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'appLocaleChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'filterMode'
        QtMocHelpers::PropertyData<int>(9, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'filterDt'
        QtMocHelpers::PropertyData<QDate>(10, QMetaType::QDate, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'filterHour'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'filterHideCompleted'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'appLocale'
        QtMocHelpers::PropertyData<QLocale>(13, QMetaType::QLocale, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<enum Status>(14, 14, QMC::EnumFlags{}).add({
            {   15, Status::StatusNone },
            {   16, Status::StatusTentative },
            {   17, Status::StatusConfirmed },
            {   18, Status::StatusCompleted },
            {   19, Status::StatusNeedsAction },
            {   20, Status::StatusCanceled },
            {   21, Status::StatusInProcess },
            {   22, Status::StatusDraft },
            {   23, Status::StatusFinal },
            {   24, Status::StatusX },
        }),
    };
    return QtMocHelpers::metaObjectData<IncidenceModel, qt_meta_tag_ZN14IncidenceModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject IncidenceModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14IncidenceModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14IncidenceModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14IncidenceModelE_t>.metaTypes,
    nullptr
} };

void IncidenceModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IncidenceModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->filterDtChanged(); break;
        case 1: _t->filterHourChanged(); break;
        case 2: _t->filterHideCompletedChanged(); break;
        case 3: _t->calendarFilterChanged(); break;
        case 4: _t->calendarChanged(); break;
        case 5: _t->filterModeChanged(); break;
        case 6: _t->appLocaleChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IncidenceModel::*)()>(_a, &IncidenceModel::filterDtChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceModel::*)()>(_a, &IncidenceModel::filterHourChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceModel::*)()>(_a, &IncidenceModel::filterHideCompletedChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceModel::*)()>(_a, &IncidenceModel::calendarFilterChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceModel::*)()>(_a, &IncidenceModel::calendarChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceModel::*)()>(_a, &IncidenceModel::filterModeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (IncidenceModel::*)()>(_a, &IncidenceModel::appLocaleChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->filterMode(); break;
        case 1: *reinterpret_cast<QDate*>(_v) = _t->filterDt(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->filterHour(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->filterHideCompleted(); break;
        case 4: *reinterpret_cast<QLocale*>(_v) = _t->appLocale(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setFilterMode(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setFilterDt(*reinterpret_cast<QDate*>(_v)); break;
        case 2: _t->setFilterHour(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setFilterHideCompleted(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setAppLocale(*reinterpret_cast<QLocale*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *IncidenceModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *IncidenceModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14IncidenceModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int IncidenceModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void IncidenceModel::filterDtChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void IncidenceModel::filterHourChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void IncidenceModel::filterHideCompletedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void IncidenceModel::calendarFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void IncidenceModel::calendarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void IncidenceModel::filterModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void IncidenceModel::appLocaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
