/****************************************************************************
** Meta object code from reading C++ file 'calendarcontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../calindori-26.07.90/src/calendarcontroller.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'calendarcontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18CalendarControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto CalendarController::qt_create_metaobjectdata<qt_meta_tag_ZN18CalendarControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CalendarController",
        "statusMessageChanged",
        "",
        "statusMessage",
        "messageType",
        "activeCalendarChanged",
        "importFromBuffer",
        "targetCalendar",
        "LocalCalendar*",
        "localCalendar",
        "abortImporting",
        "removeEvent",
        "QVariantMap",
        "event",
        "upsertEvent",
        "QVariantList",
        "attendeesList",
        "localSystemDateTime",
        "validateEvent",
        "eventMap",
        "removeTodo",
        "todo",
        "upsertTodo",
        "validateTodo",
        "fileNameFromUrl",
        "QUrl",
        "sourcePath",
        "exportData",
        "calendarName",
        "activeCalendar"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'statusMessageChanged'
        QtMocHelpers::SignalData<void(const QString &, const int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'activeCalendarChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'importFromBuffer'
        QtMocHelpers::MethodData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Method 'importFromBuffer'
        QtMocHelpers::MethodData<void(LocalCalendar *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Method 'abortImporting'
        QtMocHelpers::MethodData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'removeEvent'
        QtMocHelpers::MethodData<void(LocalCalendar *, const QVariantMap &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 12, 13 },
        }}),
        // Method 'upsertEvent'
        QtMocHelpers::MethodData<void(const QVariantMap &, const QVariantList &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 15, 16 },
        }}),
        // Method 'localSystemDateTime'
        QtMocHelpers::MethodData<QDateTime() const>(17, 2, QMC::AccessPublic, QMetaType::QDateTime),
        // Method 'validateEvent'
        QtMocHelpers::MethodData<QVariantMap(const QVariantMap &) const>(18, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { 0x80000000 | 12, 19 },
        }}),
        // Method 'removeTodo'
        QtMocHelpers::MethodData<void(LocalCalendar *, const QVariantMap &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 12, 21 },
        }}),
        // Method 'upsertTodo'
        QtMocHelpers::MethodData<void(LocalCalendar *, const QVariantMap &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 12, 21 },
        }}),
        // Method 'validateTodo'
        QtMocHelpers::MethodData<QVariantMap(const QVariantMap &) const>(23, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { 0x80000000 | 12, 21 },
        }}),
        // Method 'fileNameFromUrl'
        QtMocHelpers::MethodData<QString(const QUrl &)>(24, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Method 'exportData'
        QtMocHelpers::MethodData<QVariantMap(const QString &)>(27, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'activeCalendar'
        QtMocHelpers::PropertyData<LocalCalendar*>(29, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CalendarController, qt_meta_tag_ZN18CalendarControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CalendarController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CalendarControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CalendarControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18CalendarControllerE_t>.metaTypes,
    nullptr
} };

void CalendarController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CalendarController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->statusMessageChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->activeCalendarChanged(); break;
        case 2: _t->importFromBuffer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->importFromBuffer((*reinterpret_cast<std::add_pointer_t<LocalCalendar*>>(_a[1]))); break;
        case 4: _t->abortImporting(); break;
        case 5: _t->removeEvent((*reinterpret_cast<std::add_pointer_t<LocalCalendar*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 6: _t->upsertEvent((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2]))); break;
        case 7: { QDateTime _r = _t->localSystemDateTime();
            if (_a[0]) *reinterpret_cast<QDateTime*>(_a[0]) = std::move(_r); }  break;
        case 8: { QVariantMap _r = _t->validateEvent((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->removeTodo((*reinterpret_cast<std::add_pointer_t<LocalCalendar*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 10: _t->upsertTodo((*reinterpret_cast<std::add_pointer_t<LocalCalendar*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[2]))); break;
        case 11: { QVariantMap _r = _t->validateTodo((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 12: { QString _r = _t->fileNameFromUrl((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 13: { QVariantMap _r = _t->exportData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LocalCalendar* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LocalCalendar* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LocalCalendar* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< LocalCalendar* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CalendarController::*)(const QString & , const int )>(_a, &CalendarController::statusMessageChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalendarController::*)()>(_a, &CalendarController::activeCalendarChanged, 1))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< LocalCalendar* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<LocalCalendar**>(_v) = _t->activeCalendar(); break;
        default: break;
        }
    }
}

const QMetaObject *CalendarController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CalendarController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18CalendarControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CalendarController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void CalendarController::statusMessageChanged(const QString & _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void CalendarController::activeCalendarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
