/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.calindac.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "calindacadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class CalindacAdaptor
 */

CalindacAdaptor::CalindacAdaptor(CalAlarmClient *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

CalindacAdaptor::~CalindacAdaptor()
{
    // destructor
}

QStringList CalindacAdaptor::dumpAlarms()
{
    // handle method call org.kde.calindac.dumpAlarms
    return parent()->dumpAlarms();
}

QString CalindacAdaptor::dumpLastCheck()
{
    // handle method call org.kde.calindac.dumpLastCheck
    return parent()->dumpLastCheck();
}

void CalindacAdaptor::forceAlarmCheck()
{
    // handle method call org.kde.calindac.forceAlarmCheck
    parent()->forceAlarmCheck();
}

void CalindacAdaptor::quit()
{
    // handle method call org.kde.calindac.quit
    parent()->quit();
}

void CalindacAdaptor::scheduleAlarmCheck()
{
    // handle method call org.kde.calindac.scheduleAlarmCheck
    parent()->scheduleAlarmCheck();
}


#include "moc_calindacadaptor.cpp"
