/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.wakeupmanager.PowerManagement.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "powermanagementadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class PowerManagementAdaptor
 */

PowerManagementAdaptor::PowerManagementAdaptor(WakeupManager *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

PowerManagementAdaptor::~PowerManagementAdaptor()
{
    // destructor
}

void PowerManagementAdaptor::removeWakeup(int cookie)
{
    // handle method call org.kde.PowerManagement.removeWakeup
    parent()->removeWakeup(cookie);
}

void PowerManagementAdaptor::wakeupCallback(int cookie)
{
    // handle method call org.kde.PowerManagement.wakeupCallback
    parent()->wakeupCallback(cookie);
}


#include "moc_powermanagementadaptor.cpp"
