/****************************************************************************
** Meta object code from reading C++ file 'calindoriconfig.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../calindori-26.07.90/src/calindoriconfig.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'calindoriconfig.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15CalindoriConfigE_t {};
} // unnamed namespace

template <> constexpr inline auto CalindoriConfig::qt_create_metaobjectdata<qt_meta_tag_ZN15CalindoriConfigE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CalindoriConfig",
        "internalCalendarsChanged",
        "",
        "externalCalendarsChanged",
        "activeCalendarChanged",
        "eventsDurationChanged",
        "preEventRemindTimeChanged",
        "alwaysRemindChanged",
        "canAddCalendar",
        "QVariantMap",
        "calendar",
        "addInternalCalendar",
        "ownerName",
        "ownerEmail",
        "addExternalCalendar",
        "QUrl",
        "calendarPathUrl",
        "removeCalendar",
        "isExternal",
        "calendarName",
        "setOwnerInfo",
        "internalCalendars",
        "externalCalendars",
        "activeCalendar",
        "eventsDuration",
        "preEventRemindTime",
        "alwaysRemind"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'internalCalendarsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'externalCalendarsChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeCalendarChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'eventsDurationChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'preEventRemindTimeChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alwaysRemindChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'canAddCalendar'
        QtMocHelpers::SlotData<QVariantMap(const QString &)>(8, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'addInternalCalendar'
        QtMocHelpers::SlotData<QVariantMap(const QString &, const QString &, const QString &)>(11, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 12 }, { QMetaType::QString, 13 },
        }}),
        // Slot 'addInternalCalendar'
        QtMocHelpers::SlotData<QVariantMap(const QString &, const QString &)>(11, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 9, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'addInternalCalendar'
        QtMocHelpers::SlotData<QVariantMap(const QString &)>(11, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 9, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'addExternalCalendar'
        QtMocHelpers::SlotData<QVariantMap(const QString &, const QString &, const QString &, const QUrl &)>(14, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 12 }, { QMetaType::QString, 13 }, { 0x80000000 | 15, 16 },
        }}),
        // Slot 'removeCalendar'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Method 'isExternal'
        QtMocHelpers::MethodData<bool(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 19 },
        }}),
        // Method 'setOwnerInfo'
        QtMocHelpers::MethodData<void(const QString &, const QString &, const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 12 }, { QMetaType::QString, 13 },
        }}),
        // Method 'ownerName'
        QtMocHelpers::MethodData<QString(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 19 },
        }}),
        // Method 'ownerEmail'
        QtMocHelpers::MethodData<QString(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'internalCalendars'
        QtMocHelpers::PropertyData<QStringList>(21, QMetaType::QStringList, QMC::DefaultPropertyFlags, 0),
        // property 'externalCalendars'
        QtMocHelpers::PropertyData<QStringList>(22, QMetaType::QStringList, QMC::DefaultPropertyFlags, 1),
        // property 'activeCalendar'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'eventsDuration'
        QtMocHelpers::PropertyData<int>(24, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'preEventRemindTime'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'alwaysRemind'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CalindoriConfig, qt_meta_tag_ZN15CalindoriConfigE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CalindoriConfig::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalindoriConfigE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalindoriConfigE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15CalindoriConfigE_t>.metaTypes,
    nullptr
} };

void CalindoriConfig::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CalindoriConfig *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->internalCalendarsChanged(); break;
        case 1: _t->externalCalendarsChanged(); break;
        case 2: _t->activeCalendarChanged(); break;
        case 3: _t->eventsDurationChanged(); break;
        case 4: _t->preEventRemindTimeChanged(); break;
        case 5: _t->alwaysRemindChanged(); break;
        case 6: { QVariantMap _r = _t->canAddCalendar((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 7: { QVariantMap _r = _t->addInternalCalendar((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 8: { QVariantMap _r = _t->addInternalCalendar((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 9: { QVariantMap _r = _t->addInternalCalendar((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 10: { QVariantMap _r = _t->addExternalCalendar((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->removeCalendar((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: { bool _r = _t->isExternal((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->setOwnerInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 14: { QString _r = _t->ownerName((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 15: { QString _r = _t->ownerEmail((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CalindoriConfig::*)()>(_a, &CalindoriConfig::internalCalendarsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalindoriConfig::*)()>(_a, &CalindoriConfig::externalCalendarsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalindoriConfig::*)()>(_a, &CalindoriConfig::activeCalendarChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalindoriConfig::*)()>(_a, &CalindoriConfig::eventsDurationChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalindoriConfig::*)()>(_a, &CalindoriConfig::preEventRemindTimeChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CalindoriConfig::*)()>(_a, &CalindoriConfig::alwaysRemindChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->internalCalendars(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->externalCalendars(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->activeCalendar(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->eventsDuration(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->preEventRemindTime(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->alwaysRemind(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setActiveCalendar(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setEventsDuration(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setPreEventRemindTime(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setAlwaysRemind(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *CalindoriConfig::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CalindoriConfig::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15CalindoriConfigE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int CalindoriConfig::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void CalindoriConfig::internalCalendarsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void CalindoriConfig::externalCalendarsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void CalindoriConfig::activeCalendarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void CalindoriConfig::eventsDurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void CalindoriConfig::preEventRemindTimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void CalindoriConfig::alwaysRemindChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
