// This file is autogenerated. Changes will be overwritten.
#include "EWIEGA46WW/moc_alarmnotification.cpp"
#include "EWIEGA46WW/moc_alarmsmodel.cpp"
#include "EWIEGA46WW/moc_calalarmclient.cpp"
#include "EWIEGA46WW/moc_notificationhandler.cpp"
#include "EWIEGA46WW/moc_solidwakeupbackend.cpp"
#include "EWIEGA46WW/moc_wakeupmanager.cpp"
