/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.wakeupmanager.PowerManagement.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef POWERMANAGEMENTADAPTOR_H
#define POWERMANAGEMENTADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "wakeupmanager.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.PowerManagement
 */
class PowerManagementAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.PowerManagement")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.PowerManagement\">\n"
"    <method name=\"wakeupCallback\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"cookie\"/>\n"
"    </method>\n"
"    <method name=\"removeWakeup\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"cookie\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    PowerManagementAdaptor(WakeupManager *parent);
    ~PowerManagementAdaptor() override;

    inline WakeupManager *parent() const
    { return static_cast<WakeupManager *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void removeWakeup(int cookie);
    void wakeupCallback(int cookie);
Q_SIGNALS: // SIGNALS
};

#endif
