/****************************************************************************
** Meta object code from reading C++ file 'recurrenceperiodmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../calindori-26.07.90/src/recurrenceperiodmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'recurrenceperiodmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21ReccurencePeriodModelE_t {};
} // unnamed namespace

template <> constexpr inline auto ReccurencePeriodModel::qt_create_metaobjectdata<qt_meta_tag_ZN21ReccurencePeriodModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ReccurencePeriodModel",
        "periodDecription",
        "",
        "periodType",
        "repeatDescription",
        "repeatType",
        "repeatEvery",
        "stopAfter",
        "noRepeat",
        "repeatYearlyDay",
        "repeatYearlyMonth",
        "repeatYearlyPos",
        "repeatMonthlyDay",
        "repeatMonthlyPos",
        "repeatWeekly",
        "repeatDaily"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'periodDecription'
        QtMocHelpers::MethodData<QString(const int) const>(1, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 3 },
        }}),
        // Method 'repeatDescription'
        QtMocHelpers::MethodData<QString(const int, const int, const int) const>(4, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 5 }, { QMetaType::Int, 6 }, { QMetaType::Int, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'noRepeat'
        QtMocHelpers::PropertyData<ushort>(8, QMetaType::UShort, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'repeatYearlyDay'
        QtMocHelpers::PropertyData<ushort>(9, QMetaType::UShort, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'repeatYearlyMonth'
        QtMocHelpers::PropertyData<ushort>(10, QMetaType::UShort, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'repeatYearlyPos'
        QtMocHelpers::PropertyData<ushort>(11, QMetaType::UShort, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'repeatMonthlyDay'
        QtMocHelpers::PropertyData<ushort>(12, QMetaType::UShort, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'repeatMonthlyPos'
        QtMocHelpers::PropertyData<ushort>(13, QMetaType::UShort, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'repeatWeekly'
        QtMocHelpers::PropertyData<ushort>(14, QMetaType::UShort, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'repeatDaily'
        QtMocHelpers::PropertyData<ushort>(15, QMetaType::UShort, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ReccurencePeriodModel, qt_meta_tag_ZN21ReccurencePeriodModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ReccurencePeriodModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ReccurencePeriodModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ReccurencePeriodModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21ReccurencePeriodModelE_t>.metaTypes,
    nullptr
} };

void ReccurencePeriodModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ReccurencePeriodModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QString _r = _t->periodDecription((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 1: { QString _r = _t->repeatDescription((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<ushort*>(_v) = _t->noRepeat(); break;
        case 1: *reinterpret_cast<ushort*>(_v) = _t->repeatYearlyDay(); break;
        case 2: *reinterpret_cast<ushort*>(_v) = _t->repeatYearlyMonth(); break;
        case 3: *reinterpret_cast<ushort*>(_v) = _t->repeatYearlyPos(); break;
        case 4: *reinterpret_cast<ushort*>(_v) = _t->repeatMonthlyDay(); break;
        case 5: *reinterpret_cast<ushort*>(_v) = _t->repeatMonthlyPos(); break;
        case 6: *reinterpret_cast<ushort*>(_v) = _t->repeatWeekly(); break;
        case 7: *reinterpret_cast<ushort*>(_v) = _t->repeatDaily(); break;
        default: break;
        }
    }
}

const QMetaObject *ReccurencePeriodModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ReccurencePeriodModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ReccurencePeriodModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int ReccurencePeriodModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
